<img src=".github/sara.png" align="right" width="100">

Panda3D Sprite
==============
![GitHub issues](https://img.shields.io/github/issues/NxtStudios/p3d-sprite?style=for-the-badge)
![PyPI - Status](https://img.shields.io/pypi/status/panda3d_sprite?style=for-the-badge)
![Engine](https://img.shields.io/static/v1?style=for-the-badge&label=Engine&message=Panda3D&color=red)

The panda3d-sprite module provides spritesheet capabilities to the Panda3D game engine. This module is a modification and slight redesign of work done by Panda3D forum user ZeroByte. The original forum post can be located <a href="https://discourse.panda3d.org/t/pixel-art-sprite-cards/5142">here</a>

panda3d-sprite can be used to load static sprites, animated sprites, and layered sprites for sprites with clothing options.

<img src="https://i.gyazo.com/acc3939721b932bcff71382ba707b21f.gif" width="400"/>

## Install

```
pip install panda3d-sprite
```

## Dependencies
* Python 3.7
* Panda3d 1.10.0 or newer

## Credits
The sprite sheet used for p3d-sprite examples was created by Stephen "Redshrike" Challenger and William Thompsonj. The original open game art link for the sprite can be found <a href="https://opengameart.org/content/lpc-sara">here</a>

## License
p3d-sprite is available under the MIT license. A copy of this license can be found with the source code. If one was not provided its available <a href="https://github.com/NxtStudios/p3d-sprite/blob/master/LICENSE">here</a>
